Comprehensive AI Toolkit for Multimodal Learning and Cross-Platform Robotics
=============================================================================

.. include:: ../../README.rst
   :start-after: .. index-start
   :end-before: .. index-end

Iamai is not just a library; it's a comprehensive AI toolkit that brings together multimodal machine learning and cross-platform robotics. Whether you're developing intelligent systems or constructing robots for various platforms, iamai is your go-to solution for a unified and powerful development experience. Explore the possibilities with iamai today!

This documentation is based on Alicebot `Docs <https://docs.alicebot.dev>`_, but with some modifications and improvements. It still has many shortcomings and is currently under reconstruction.

.. toctree::
   :hidden:

   pages/starting/getting-started

.. toctree::
   :caption: Basic
   :hidden:

   pages/basic/basic-config
   pages/basic/plugin-basics
   pages/basic/builtin-message

.. toctree::
   :caption: Advanced
   :hidden:

   pages/advanced/plugin-advanced
   pages/advanced/hot-reload
   pages/advanced/scheduler
   pages/advanced/hook-function

.. toctree::
   :caption: Adapters
   :hidden:

   pages/adapters/cqhttp-adapter
   pages/adapters/mirai-adapter
   pages/adapters/dingtalk-adapter

.. toctree::
   :caption: Development
   :hidden:

   API Documentation <pages/api/index.rst>
   Contributing <pages/development/contributing.rst>
   Changelog <changelog.rst>
   COPYING <COPYING.rst>

.. toctree::
   :caption: Community
   :hidden:

   Assets Library <pages/community/assets-library.rst>
   Development Blog <pages/blog/index.rst>

.. toctree::
   :caption: Thanks and credits
   :hidden:

   Credits <credits>
